@@ -2,4 +2,4 @@ from spackle.customer import Customer
 from spackle.exceptions import SpackleException
 
 api_key = None
-api_base = "https://www.spackle.so/api/v1"
+api_base = "https://www.spackle.so/edge/v1"
